@@ -800,6 +800,10 @@ VALIDATE_TASK_SCHEMA = '''{
                             "default": false,
                             "type": "boolean"
                         },
+                        "ferry_crossing": {
+                            "default": true,
+                            "type": "boolean"
+                        },
                         "flight_distance": {
                             "default": false,
                             "type": "boolean"
@@ -808,6 +812,10 @@ VALIDATE_TASK_SCHEMA = '''{
                             "default": false,
                             "type": "boolean"
                         },
+                        "toll_roads": {
+                            "default": true,
+                            "type": "boolean"
+                        },
                         "traffic_jams": {
                             "default": true,
                             "type": "boolean"
